pub struct LspTextEdit {
pub range: Range,
pub new_text: String,
}Expand description
Re-export TextEdit so callers don’t need a direct lsp-types dependency.
A textual edit applicable to a text document.
If n TextEdits are applied to a text document all text edits describe changes to the initial document version.
Execution wise text edits should applied from the bottom to the top of the text document. Overlapping text edits
are not supported.
Fields
range: RangeThe range of the text document to be manipulated. To insert text into a document create a range where start === end.
new_text: StringThe string to be inserted. For delete operations use an empty string.
Implementations